==> haskell-unordered-containers-0.2.10.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unordered-containers
version: 0.2.10.0
id: unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
key: unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
license: BSD-3-Clause
copyright: 2010-2014 Johan Tibell
           2010 Edward Z. Yang
maintainer: johan.tibell@gmail.com
author: Johan Tibell
homepage: https://github.com/tibbe/unordered-containers
synopsis: Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.
    .
    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.
category: Data
abi: e7f746d19afe63931a1ac59ff404cb99
exposed: True
exposed-modules:
    Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
hidden-modules: Data.HashMap.Array Data.HashMap.Base
                Data.HashMap.Strict.Base Data.HashMap.List Data.HashMap.Unsafe
                Data.HashMap.UnsafeShift Data.HashSet.Base
import-dirs: /usr/lib/ghc-8.6.5/site-local/unordered-containers-0.2.10.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/unordered-containers-0.2.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/unordered-containers-0.2.10.0
hs-libraries: HSunordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
haddock-interfaces: /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock
haddock-html: /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unordered-containers-0.2.10.0-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unordered-containers
version: 0.2.10.0
id: unordered-containers-0.2.10.0-HXsxAsTvm9z649814xbQu4
key: unordered-containers-0.2.10.0-HXsxAsTvm9z649814xbQu4
license: BSD-3-Clause
copyright: 2010-2014 Johan Tibell
           2010 Edward Z. Yang
maintainer: johan.tibell@gmail.com
author: Johan Tibell
homepage: https://github.com/tibbe/unordered-containers
synopsis: Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.
    .
    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.
category: Data
abi: 08673482520d35a89b8deb77c38ca94e
exposed: True
exposed-modules:
    Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
hidden-modules: Data.HashMap.Array Data.HashMap.Base
                Data.HashMap.Strict.Base Data.HashMap.List Data.HashMap.Unsafe
                Data.HashMap.UnsafeShift Data.HashSet.Base
import-dirs: /usr/lib/ghc-8.6.5/site-local/unordered-containers-0.2.10.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/unordered-containers-0.2.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/unordered-containers-0.2.10.0
hs-libraries: HSunordered-containers-0.2.10.0-HXsxAsTvm9z649814xbQu4
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
haddock-interfaces: /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock
haddock-html: /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
